import matplotlib.pyplot as plt
import matplotlib.patches as patches

# Data: Points (x, y)
points_x = [8, 10, 5, 1, 2, 8, 3, 1]
points_y = [8, 1, 4, 5, 1, 6, 1, 4]

# Rhomboid data: each has a center and a diagonal length
rhomboids = [
    {'center': (1, 0), 'diagonal_length': 4},
    {'center': (2, 0), 'diagonal_length': 12},
    {'center': (6, 0), 'diagonal_length': 14}
]

# Colors for each rhomboid
rhomboid_colors = ['red', 'green', 'purple']

# Set up the plot
fig, ax = plt.subplots(figsize=(8, 8))
ax.set_aspect('equal')
ax.set_xlim(0, 15)
ax.set_ylim(0, 15)
ax.grid(True)

# Plot points
ax.scatter(points_x, points_y, color='blue', label='Points')

# Plot each rhomboid with different colors and mark their centers
for rhom, color in zip(rhomboids, rhomboid_colors):
    cx, cy = rhom['center']
    d = rhom['diagonal_length'] / 2  # half of diagonal length

    # Define rhomboid vertices based on diagonal lengths
    rhomboid = patches.Polygon([
        (cx - d, cy),  # Left point on x-axis diagonal
        (cx, cy + d),  # Top point on y-axis diagonal
        (cx + d, cy),  # Right point on x-axis diagonal
        (cx, cy - d)   # Bottom point on y-axis diagonal
    ], closed=True, edgecolor=color, facecolor='none', linewidth=1.5, label=f'Rhomboid at {cx, cy}')
    
    ax.add_patch(rhomboid)

    # Mark the center of each rhomboid with an "X"
    ax.plot(cx, cy, marker='x', color=color, markersize=10, markeredgewidth=2)

# Add labels and legend
ax.set_xlabel("X")
ax.set_ylabel("Y")
ax.legend(loc="upper right")

# Show the plot
plt.show()

